@@ -1,4 +1,12 @@
-from ._version import __version__
+try:
+    from ._version import __version__
+except ImportError:
+    # Fallback when using the package in dev mode without installing
+    # in editable mode with pip. It is highly recommended to install
+    # the package from a stable release or in editable mode: https://pip.pypa.io/en/stable/topics/local-project-installs/#editable-installs
+    import warnings
+    warnings.warn("Importing 'jupyterlab_nbqueue' outside a proper installation.")
+    __version__ = "dev"
 from .handlers import setup_handlers
 
 
@@ -26,7 +34,3 @@ def _load_jupyter_server_extension(server_app):
     setup_handlers(server_app.web_app)
     name = "jupyterlab_nbqueue"
     server_app.log.info(f"Registered {name} server extension")
-
-
-# For backward compatibility with notebook server - useful for Binder/JupyterHub
-load_jupyter_server_extension = _load_jupyter_server_extension
